/**
 * Title:       Offer queue sender for job2me project
 * ClassName:   OfferSenderNoReply.java
 * Created:     March 22, 2015
 * Author:      Claudiu Vinte
 * Department:  Economic Informatics, The Bucharest University of Economic Studies
 *
 * Description: Implements an Offer queue sender, by extending AbstractQueueSenderNoReply class
 */

package job2me.jms.api;

import job2me.data.api.Offer;
import job2me.data.api.Enums;

import javax.jms.JMSException;
import javax.jms.ObjectMessage;


public class OfferSenderNoReply extends AbstractQueueSenderNoReply
{
    public OfferSenderNoReply(String imqAddress, String queueName, String userID)
            throws JMSException, Exception
    {
        super(imqAddress, queueName, userID);
    }

    // Create and send an Offer message
    public void sendOffer(Offer offer) throws JMSException
    {
        // Construct the message as an ObjectMessage (Offer)
        ObjectMessage message = this.getSession().createObjectMessage();
        message.setObject(offer);

        message.setStringProperty("MSG_TYPE", Enums.MessageType.OFFER.toString());
        message.setStringProperty("USER_ID", this.getUserID());

        // Company Offers are received by DOME
        
        // TO DO in the derived class

        this.getSender().send(message);
    }
    
}

